@@ -6,16 +6,25 @@ from beancount.core import prices
 from beancount.core import realization
 from beancount.query import query
 from beancount.core.data import Open
+from beancount.core.data import Custom
+import ast
+
 
 class AccAPI:
     def __init__(self, beancount_file, options):
         self.entries, _, self.options_map = loader.load_file(beancount_file)
         self.options = options
-        self.begin = self.end = None # Only used in fava
+
+    def end_date(self):
+        return None  # Only used in fava (UI selection context)
 
     def build_price_map(self):
         return prices.build_price_map(self.entries)
 
+    def build_filtered_price_map(self, pos, base_currency):
+        """Ignore filtering since we are not in fava. Return all prices"""
+        return prices.build_price_map(self.entries)
+
     def get_commodity_directives(self):
         return getters.get_commodity_directives(self.entries)
 
@@ -46,7 +55,7 @@ class AccAPI:
 
     def get_account_open(self):
         oc = getters.get_account_open_close(self.entries)
-        opens = [e for e in oc if isintance(e, Open)]
+        opens = [v for k, v in oc.items() if isinstance(v[0], Open)]
         return opens
 
     # def cost_or_value(self, node, date, include_children):
@@ -55,3 +64,18 @@ class AccAPI:
     #         return cost_or_value(node.balance_children, date)
     #     return cost_or_value(node.balance, date)
 
+    def get_custom_config(self, module_name):
+        """Get fava config for the given plugin that can then be used on the command line"""
+        _extension_entries = [e for e in self.entries
+                              if isinstance(e, Custom) and e.type == 'fava-extension']
+        config_meta = {entry.values[0].value:
+                       (entry.values[1].value if (len(entry.values) == 2) else None)
+                       for entry in _extension_entries}
+
+        all_configs = {k: ast.literal_eval(v) for k, v in config_meta.items() if 'fava_investor' in k}
+
+        # extract conig for just this module:
+        module_config = [v[module_name] for k, v in all_configs.items() if module_name in v]
+        if module_config:
+            return module_config[0]
+        return {}
